==> lablaster_0.0.1.tar.gz: lablaster/R/data.R <==
#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' An antepenultimate chamber of Menardella exilis foraminifera 72, identified hereon as “foram72shot3”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram72shot3"


#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' An antepenultimate chamber of Menardella exilis foraminifera 174, identified hereon as “foram174shot4”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram174shot4"

#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' The fifth from final chamber of Menardella exilis foraminifera 166, identified hereon as “foram166shot7”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram166shot7"

#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a branching coral, identified hereon as “coral6”.
#'
#' A coral from Chris Standish.
#'
#' @format A data frame with 300 rows and 5 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in milliseconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Sr86}{raw data for 86Sr}
#' }
"coral6"

==> lablaster_1.0.1.tar.gz: lablaster/R/data.R <==
#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' An antepenultimate chamber of Menardella exilis foraminifera 72, identified hereon as “foram72shot3”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram72shot3"


#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' An antepenultimate chamber of Menardella exilis foraminifera 174, identified hereon as “foram174shot4”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram174shot4"

#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a planktonic foraminifera
#'
#' The fifth from final chamber of Menardella exilis foraminifera 166, identified hereon as “foram166shot7”.
#'
#' @format A data frame with 144 rows and 8 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in seconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Al27}{raw data for 27Al}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Ca44}{raw data for 44Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Cu65}{raw data for 65Cu}
#'   \item{Sr88}{raw data for 88Sr}
#' }
"foram166shot7"

#' Time resolved analysis by laser ablation inductively coupled plasma mass spectrometry of a branching coral, identified hereon as “coral6”.
#'
#' A fragment of Acropora polystoma coral from Chris Standish.
#'
#' @format A data frame with 300 rows and 5 variables:
#' \describe{
#'   \item{Time}{time stamp of each observation (in milliseconds)}
#'   \item{Mg24}{raw data for 24Mg}
#'   \item{Ca43}{raw data for 43Ca}
#'   \item{Mn55}{raw data for 55Mn}
#'   \item{Sr86}{raw data for 86Sr}
#' }
"coral6"
